# GlusterFS
On all Nodes (except HAProxy)
```
$ sudo add-apt-repository ppa:gluster/glusterfs-10
$ sudo apt-get update
$ sudo apt-get install glusterfs-server
```
Attached HDD: 500GB
```
$ sudo parted /dev/sdb mklabel gpt
$ sudo parted -a opt /dev/sdb mkpart primary 0% 100%
$ sudo parted -s -- /dev/sdb set 1 lvm on
```
LVM with Gluster needs a thin pool
```
$ sudo pvcreate --dataalignment 128K /dev/sdb1
$ sudo vgcreate --physicalextentsize 128K gfs_vg /dev/sdb1
$ sudo lvcreate -L 8G --name gfs_pool_meta gfs_vg
$ sudo lvcreate -L 480G --name gfs_pool gfs_vg
$ sudo lvconvert --chunksize 128K --thinpool gfs_vg/gfs_pool --poolmetadata gfs_vg/gfs_pool_meta
$ sudo lvchange --zero n gfs_vg/gfs_pool
$ sudo lvcreate -V 480G -T gfs_vg/gfs_pool -n gfs_lv
$ sudo mkfs.xfs -f -i size=512 -n size=8192 -d su=128k,sw=1 /dev/gfs_vg/gfs_lv
```

```
$ sudo mkdir -pv /opt/oea/glusterfs
$ echo "echo '/dev/gfs_vg/gfs_lv /opt/oea/glusterfs xfs defaults 1 2' >> /etc/fstab" | sudo -s
$ sudo mount -a
```

```
$ sudo systemctl restart glusterd
$ sudo systemctl status glusterd
```

# initial node

```
$ export GLUSTERFS_NODE01_FQDN=<Node01_FQDN>
$ export GLUSTERFS_NODE01_IP=<Node01_IP>
```

```
$ sudo openssl genrsa -out /etc/ssl/glusterfs.key 4096
$ sudo chmod -v 600 /etc/ssl/glusterfs.key
$ sudo openssl req -new -x509 -days 365 -key /etc/ssl/glusterfs.key -subj "/CN=$GLUSTERFS_NODE01_FQDN" -out /etc/ssl/glusterfs.pem
```

```
$ echo 'cat /etc/ssl/glusterfs.pem > /etc/ssl/glusterfs.ca' | sudo -s
```

```
$ sudo touch /var/lib/glusterd/secure-access
```

```
$ sudo systemctl restart glusterd
```

```
$ sudo mkdir -pv /opt/oea/glusterfs/oea
```

```
$ sudo gluster volume create oea $GLUSTERFS_NODE01_FQDN:/opt/oea/glusterfs/oea
$ sudo gluster volume set oea auth.allow $GLUSTERFS_NODE01_IP
$ sudo gluster volume set oea auth.ssl-allow "$GLUSTERFS_NODE01_FQDN"
$ sudo gluster volume set oea client.ssl on
$ sudo gluster volume set oea server.ssl on
$ sudo gluster volume set oea ssl.cipher-list 'HIGH:!SSLv2'
```

```
$ sudo gluster volume start oea
```

```
$ sudo gluster volume info
$ sudo gluster volume list
$ sudo gluster volume status
```

```
$ sudo mkdir -pv /opt/oea/mnt/glusterfs
$ echo "echo 'localhost:/oea /opt/oea/mnt/glusterfs glusterfs defaults,_netdev,noauto,x-systemd.automount 0 0' >> /etc/fstab" | sudo -s
$ sudo mount -a
```

```
$ sudo shutdown -r now
... Please wait until system has restarted and login again ...
$ sudo systemctl restart glusterd
$ sudo gluster volume start oea
```

## extra config gluster volume

GlusterFS <= 3.10.1 needs extra configuration to work with Elasticsearch data files. See [https://bugzilla.redhat.com/show_bug.cgi?id=1379568](https://bugzilla.redhat.com/show_bug.cgi?id=1379568) for why. Even though GlusterFS > 3.10.1 this configuration might be needed.

```
$ sudo gluster volume get oea all | grep -E 'performance.quick-read|performance.io-cache|performance.write-behind|performance.stat-prefetch|performance.read-ahead|performance.readdir-ahead|performance.open-behind|performance.client-io-threads'
performance.write-behind-window-size    1MB
performance.read-ahead-page-count       4
performance.write-behind                on
performance.read-ahead                  on
performance.readdir-ahead               on
performance.io-cache                    on
performance.quick-read                  on
performance.open-behind                 on
performance.stat-prefetch               on
performance.client-io-threads           off
```

```
$ sudo gluster volume stop oea
```

```
$ sudo gluster volume set oea performance.write-behind off
$ sudo gluster volume set oea performance.read-ahead off
$ sudo gluster volume set oea performance.readdir-ahead off
$ sudo gluster volume set oea performance.io-cache off
$ sudo gluster volume set oea performance.quick-read off
$ sudo gluster volume set oea performance.open-behind off
$ sudo gluster volume set oea performance.stat-prefetch off
$ sudo gluster volume set oea performance.client-io-threads off
```

```
$ sudo gluster volume start oea
```

## renew certificate

```
$ openssl x509 -enddate -noout -in /etc/ssl/glusterfs.ca
```

```
$ sudo systemctl stop glusterd
```

```
$ sudo openssl req -new -x509 -days 365 -key /etc/ssl/glusterfs.key -subj "/CN=$GLUSTERFS_NODE01_FQDN" -out /etc/ssl/glusterfs.pem
$ echo 'cat /etc/ssl/glusterfs.pem > /etc/ssl/glusterfs.ca' | sudo -s
```

```
$ sudo systemctl start glusterd
```
For the Node 2..X follow the [Join](./join) description.
